pub enum HeightmapType {
WorldSurface,
MotionBlocking,
MotionBlockingNoLeaves,
OceanFloor,
WorldSurfaceWg,
OceanFloorWg,
}Expand description
The different types of heightmaps.
Variants
WorldSurface
Tracks the highest non-air block. Used for world surface calculations.
MotionBlocking
Tracks the highest motion-blocking block (solid or fluid).
MotionBlockingNoLeaves
Tracks the highest motion-blocking block that is not leaves.
OceanFloor
Tracks the highest solid block (ocean floor).
WorldSurfaceWg
Worldgen version of WorldSurface.
OceanFloorWg
Worldgen version of OceanFloor.
Implementations
Sourceimpl HeightmapType
impl HeightmapType
const WORLD_SURFACE_MASK: u8
const MOTION_BLOCKING_MASK: u8
const MOTION_BLOCKING_NO_LEAVES_MASK: u8
const OCEAN_FLOOR_MASK: u8
const WORLD_SURFACE_WG_MASK: u8
const OCEAN_FLOOR_WG_MASK: u8
Sourcepub const fn worldgen_types() -> &'static [HeightmapType]
pub const fn worldgen_types() -> &'static [HeightmapType]
Returns worldgen heightmap types (used before CARVERS status).
Sourcepub const fn final_types() -> &'static [HeightmapType]
pub const fn final_types() -> &'static [HeightmapType]
Returns final heightmap types (used at CARVERS status and after).
Sourcepub const fn all_types() -> &'static [HeightmapType]
pub const fn all_types() -> &'static [HeightmapType]
Returns all heightmap types in their stable persistence order.
pub(crate) const fn persistence_id(self) -> u8
pub(crate) const fn from_persistence_id(id: u8) -> Option<Self>
Sourcepub fn is_opaque(self, state: BlockStateId) -> bool
pub fn is_opaque(self, state: BlockStateId) -> bool
Returns whether a block is “opaque” for this heightmap type. This determines whether the block counts towards the heightmap.
Panics
Panics if the block state ID is invalid.
const fn mask(self) -> u8